part: Drop disk_partition_t typedef
authorSimon Glass <sjg@chromium.org>
Sun, 10 May 2020 17:39:57 +0000 (11:39 -0600)
committerTom Rini <trini@konsulko.com>
Mon, 18 May 2020 21:33:33 +0000 (17:33 -0400)
We should not be using typedefs and these make it harder to use
forward declarations (to reduce header file inclusions). Drop the typedef.

Signed-off-by: Simon Glass <sjg@chromium.org>
56 files changed:
arch/arm/mach-omap2/utils.c
arch/arm/mach-stm32mp/cmd_stm32prog/stm32prog.c
arch/x86/cpu/quark/quark.c
board/st/common/stm32mp_dfu.c
cmd/ab_select.c
cmd/bcb.c
cmd/disk.c
cmd/fat.c
cmd/gpt.c
cmd/part.c
cmd/read.c
cmd/reiser.c
cmd/usb_mass_storage.c
cmd/zfs.c
common/android_ab.c
common/spl/spl_ext.c
common/spl/spl_mmc.c
disk/part.c
disk/part_amiga.c
disk/part_dos.c
disk/part_efi.c
disk/part_iso.c
disk/part_mac.c
drivers/dfu/dfu_mmc.c
drivers/fastboot/fb_getvar.c
drivers/fastboot/fb_mmc.c
env/ext4.c
env/fat.c
env/mmc.c
fs/btrfs/btrfs.c
fs/btrfs/btrfs.h
fs/btrfs/dev.c
fs/ext4/dev.c
fs/ext4/ext4fs.c
fs/fat/fat.c
fs/fs.c
fs/fs_internal.c
fs/reiserfs/dev.c
fs/sandbox/sandboxfs.c
fs/ubifs/ubifs.c
fs/zfs/dev.c
include/android_ab.h
include/avb_verify.h
include/btrfs.h
include/ext4fs.h
include/fat.h
include/fb_mmc.h
include/fs_internal.h
include/part.h
include/reiserfs.h
include/sandboxfs.h
include/ubifs_uboot.h
include/zfs_common.h
lib/efi_loader/efi_device_path.c
lib/efi_loader/efi_disk.c
lib/efi_loader/efi_file.c

index 0d5ca20e8e87818fd9549d42b9007acf4b76a051..6e519d8c910df798b1f4fb19f2c0dfd6ccf2b9b7 100644 (file)
@@ -90,7 +90,7 @@ static u32 omap_mmc_get_part_size(const char *part)
 {
        int res;
        struct blk_desc *dev_desc;
-       disk_partition_t info;
+       struct disk_partition info;
        u64 sz = 0;
 
        dev_desc = blk_get_dev("mmc", CONFIG_FASTBOOT_FLASH_MMC_DEV);
index cc303214cf6d5470ce7c567bfe7bdb31f5487080..65cb12dbcfdaa0583f87b3b201dd340ba112e690 100644 (file)
@@ -727,7 +727,7 @@ static int init_device(struct stm32prog_data *data,
                                pr_debug("\n");
                                continue;
                        }
-                       disk_partition_t partinfo;
+                       struct disk_partition partinfo;
 
                        ret = part_get_info(block_dev, part->part_id,
                                            &partinfo);
index d6611eea5dc9e08b03cf405fef69efcd1401b50e..46c6d00eb4db9daabd9283d9e4433bdc8be7b8b5 100644 (file)
@@ -6,6 +6,7 @@
 #include <common.h>
 #include <cpu_func.h>
 #include <mmc.h>
+#include <asm/cache.h>
 #include <asm/io.h>
 #include <asm/ioapic.h>
 #include <asm/irq.h>
index 3bd005bb04adec3448931301f7236f1028d104c9..0cda9196f938d058d267162681393a3ba71a07c1 100644 (file)
@@ -17,7 +17,7 @@
 
 static void board_get_alt_info_mmc(struct udevice *dev, char *buf)
 {
-       disk_partition_t info;
+       struct disk_partition info;
        int p, len, devnum;
        bool first = true;
        const char *name;
index 7c8f2ee8eb3acd29f0f9eeba85a5fe7117b8aaba..d0d957d4f9d67a653f63ecf030d84c1f2414e24e 100644 (file)
@@ -11,7 +11,7 @@ static int do_ab_select(cmd_tbl_t *cmdtp, int flag, int argc,
 {
        int ret;
        struct blk_desc *dev_desc;
-       disk_partition_t part_info;
+       struct disk_partition part_info;
        char slot[2];
 
        if (argc != 4)
index 9626f2c69e345c984c83a730fdae1ba3bd11024d..62f9a44e38a35a078c4fd496b2a7f62f2ffe40a3 100644 (file)
--- a/cmd/bcb.c
+++ b/cmd/bcb.c
@@ -112,7 +112,7 @@ static int do_bcb_load(cmd_tbl_t *cmdtp, int flag, int argc,
                       char * const argv[])
 {
        struct blk_desc *desc;
-       disk_partition_t info;
+       struct disk_partition info;
        u64 cnt;
        char *endp;
        int part, ret;
@@ -252,7 +252,7 @@ static int do_bcb_store(cmd_tbl_t *cmdtp, int flag, int argc,
                        char * const argv[])
 {
        struct blk_desc *desc;
-       disk_partition_t info;
+       struct disk_partition info;
        u64 cnt;
        int ret;
 
index 15973b7d132e19ee1e07621001057b8547156564..9e008a388906fec9b5cc54523150e02f53f0e1ea 100644 (file)
@@ -16,7 +16,7 @@ int common_diskboot(cmd_tbl_t *cmdtp, const char *intf, int argc,
        int part;
        ulong addr = CONFIG_SYS_LOAD_ADDR;
        ulong cnt;
-       disk_partition_t info;
+       struct disk_partition info;
 #if defined(CONFIG_LEGACY_IMAGE_FORMAT)
        image_header_t *hdr;
 #endif
index 28fca501fa670d078791871a666ba29949f38aeb..854fe274bcf4c758d00389c86857cdbd3eb25b1f 100644 (file)
--- a/cmd/fat.c
+++ b/cmd/fat.c
@@ -64,7 +64,7 @@ static int do_fat_fsinfo(cmd_tbl_t *cmdtp, int flag, int argc,
 {
        int dev, part;
        struct blk_desc *dev_desc;
-       disk_partition_t info;
+       struct disk_partition info;
 
        if (argc < 2) {
                printf("usage: fatinfo <interface> [<dev[:part]>]\n");
@@ -101,7 +101,7 @@ static int do_fat_fswrite(cmd_tbl_t *cmdtp, int flag,
        unsigned long count;
        long offset;
        struct blk_desc *dev_desc = NULL;
-       disk_partition_t info;
+       struct disk_partition info;
        int dev = 0;
        int part = 1;
        void *buf;
index 98c788e75793f306dd615e52c8de9925c531b25e..f2b1ad5489bc6ad79f5001521cb4cf3fb6d4f001 100644 (file)
--- a/cmd/gpt.c
+++ b/cmd/gpt.c
@@ -189,7 +189,8 @@ static void del_gpt_info(void)
        }
 }
 
-static struct disk_part *allocate_disk_part(disk_partition_t *info, int partnum)
+static struct disk_part *allocate_disk_part(struct disk_partition *info,
+                                           int partnum)
 {
        struct disk_part *newpart;
        newpart = calloc(1, sizeof(struct disk_part));
@@ -310,7 +311,7 @@ static int get_gpt_info(struct blk_desc *dev_desc)
 {
        /* start partition numbering at 1, as U-Boot does */
        int valid_parts = 0, p, ret;
-       disk_partition_t info;
+       struct disk_partition info;
        struct disk_part *new_disk_part;
 
        /*
@@ -375,14 +376,14 @@ static int do_get_gpt_info(struct blk_desc *dev_desc)
 static int set_gpt_info(struct blk_desc *dev_desc,
                        const char *str_part,
                        char **str_disk_guid,
-                       disk_partition_t **partitions,
+                       struct disk_partition **partitions,
                        u8 *parts_count)
 {
        char *tok, *str, *s;
        int i;
        char *val, *p;
        int p_count;
-       disk_partition_t *parts;
+       struct disk_partition *parts;
        int errno = 0;
        uint64_t size_ll, start_ll;
        lbaint_t offset = 0;
@@ -440,7 +441,7 @@ static int set_gpt_info(struct blk_desc *dev_desc,
        }
 
        /* allocate memory for partitions */
-       parts = calloc(sizeof(disk_partition_t), p_count);
+       parts = calloc(sizeof(struct disk_partition), p_count);
        if (parts == NULL)
                return -ENOMEM;
 
@@ -557,7 +558,7 @@ static int gpt_default(struct blk_desc *blk_dev_desc, const char *str_part)
        int ret;
        char *str_disk_guid;
        u8 part_count = 0;
-       disk_partition_t *partitions = NULL;
+       struct disk_partition *partitions = NULL;
 
        /* fill partitions */
        ret = set_gpt_info(blk_dev_desc, str_part,
@@ -584,7 +585,7 @@ static int gpt_verify(struct blk_desc *blk_dev_desc, const char *str_part)
 {
        ALLOC_CACHE_ALIGN_BUFFER_PAD(gpt_header, gpt_head, 1,
                                     blk_dev_desc->blksz);
-       disk_partition_t *partitions = NULL;
+       struct disk_partition *partitions = NULL;
        gpt_entry *gpt_pte = NULL;
        char *str_disk_guid;
        u8 part_count = 0;
@@ -640,7 +641,7 @@ static int do_rename_gpt_parts(struct blk_desc *dev_desc, char *subcomm,
 {
        struct list_head *pos;
        struct disk_part *curr;
-       disk_partition_t *new_partitions = NULL;
+       struct disk_partition *new_partitions = NULL;
        char disk_guid[UUID_STR_LEN + 1];
        char *partitions_list, *str_disk_guid = NULL;
        u8 part_count = 0;
index 5e4e45ca6d8bebe58a438223cce4c7c80177e58e..4b2e06e615af9a5feded873b91284b0d28934ce0 100644 (file)
@@ -32,7 +32,7 @@ static int do_part_uuid(int argc, char * const argv[])
 {
        int part;
        struct blk_desc *dev_desc;
-       disk_partition_t info;
+       struct disk_partition info;
 
        if (argc < 2)
                return CMD_RET_USAGE;
@@ -90,7 +90,7 @@ static int do_part_list(int argc, char * const argv[])
        if (var != NULL) {
                int p;
                char str[512] = { '\0', };
-               disk_partition_t info;
+               struct disk_partition info;
 
                for (p = 1; p < MAX_SEARCH_PARTITIONS; p++) {
                        char t[5];
@@ -117,7 +117,7 @@ static int do_part_list(int argc, char * const argv[])
 static int do_part_info(int argc, char * const argv[], enum cmd_part_info param)
 {
        struct blk_desc *desc;
-       disk_partition_t info;
+       struct disk_partition info;
        char buf[512] = { 0 };
        char *endp;
        int part;
index 82c2d9ad994ed1800c9c757b915ba67a018b8251..7977e9d847e676761616d248ec8a7b8ccb53b869 100644 (file)
@@ -18,7 +18,7 @@ int do_read(cmd_tbl_t *cmdtp, int flag, int argc, char * const argv[])
        struct blk_desc *dev_desc = NULL;
        int dev;
        int part = 0;
-       disk_partition_t part_info;
+       struct disk_partition part_info;
        ulong offset = 0u;
        ulong limit = 0u;
        void *addr;
index 598fab48b322d8231b7b9e9a66ddac103c34a49f..28e827796b32bf80251ffee142280bc3beaf455c 100644 (file)
@@ -35,7 +35,7 @@ int do_reiserls (cmd_tbl_t *cmdtp, int flag, int argc, char * const argv[])
        char *filename = "/";
        int dev, part;
        struct blk_desc *dev_desc = NULL;
-       disk_partition_t info;
+       struct disk_partition info;
 
        if (argc < 3)
                return CMD_RET_USAGE;
@@ -81,7 +81,7 @@ int do_reiserload (cmd_tbl_t *cmdtp, int flag, int argc, char * const argv[])
        char *filename = NULL;
        int dev, part;
        ulong addr = 0, filelen;
-       disk_partition_t info;
+       struct disk_partition info;
        struct blk_desc *dev_desc = NULL;
        unsigned long count;
        char *addr_str;
index c5c6899787c84a746afb30317433ab9c779f39e8..52ff637e2fb0d1d82f66537c6ce62a799fa8086f 100644 (file)
@@ -55,7 +55,7 @@ static int ums_init(const char *devtype, const char *devnums_part_str)
 {
        char *s, *t, *devnum_part_str, *name;
        struct blk_desc *block_dev;
-       disk_partition_t info;
+       struct disk_partition info;
        int partnum;
        int ret = -1;
        struct ums *ums_new;
index 9c237a5758d430e15f7d808de6851e2e5c7697c6..2b622a8f53ee9120a230d8b6dd7d0f234103312f 100644 (file)
--- a/env/fat.c
+++ b/env/fat.c
@@ -33,7 +33,7 @@ static int env_fat_save(void)
 {
        env_t __aligned(ARCH_DMA_MINALIGN) env_new;
        struct blk_desc *dev_desc = NULL;
-       disk_partition_t info;
+       struct disk_partition info;
        int dev, part;
        int err;
        loff_t size;
@@ -79,7 +79,7 @@ static int env_fat_load(void)
 {
        ALLOC_CACHE_ALIGN_BUFFER(char, buf, CONFIG_ENV_SIZE);
        struct blk_desc *dev_desc = NULL;
-       disk_partition_t info;
+       struct disk_partition info;
        int dev, part;
        int err;
 
index 251ad07d7c08f2a309667e986c5a662008c3666f..a8b661db80af45766811d7620c1b5b5d6dca23e7 100644 (file)
--- a/env/mmc.c
+++ b/env/mmc.c
@@ -27,7 +27,7 @@ DECLARE_GLOBAL_DATA_PTR;
 #if CONFIG_IS_ENABLED(OF_CONTROL)
 static inline int mmc_offset_try_partition(const char *str, s64 *val)
 {
-       disk_partition_t info;
+       struct disk_partition info;
        struct blk_desc *desc;
        int len, i, ret;
 
index 2e3985e38556795f1c324d45a3e43d8b527d139f..de16217d0dd35d1edf667b9b458a567b0c6804d8 100644 (file)
@@ -75,7 +75,8 @@ static int readdir_callback(const struct btrfs_root *root,
        return 0;
 }
 
-int btrfs_probe(struct blk_desc *fs_dev_desc, disk_partition_t *fs_partition)
+int btrfs_probe(struct blk_desc *fs_dev_desc,
+               struct disk_partition *fs_partition)
 {
        btrfs_blk_desc = fs_dev_desc;
        btrfs_part_info = fs_partition;
index 986d078679784bd3e143c834e96ebba8ad15a930..25a8cf6a8792873eb1cfcd55c77288fe3199540d 100644 (file)
@@ -36,7 +36,7 @@ static inline u64 btrfs_name_hash(const char *name, int len)
 
 /* dev.c */
 extern struct blk_desc *btrfs_blk_desc;
-extern disk_partition_t *btrfs_part_info;
+extern struct disk_partition *btrfs_part_info;
 
 int btrfs_devread(u64, int, void *);
 
index ada3800f1e1835850c409f8f4eb49649929b47de..e686abc5e3b2e73af86716bbebefb2c4337ecd27 100644 (file)
@@ -10,7 +10,7 @@
 #include <fs_internal.h>
 
 struct blk_desc *btrfs_blk_desc;
-disk_partition_t *btrfs_part_info;
+struct disk_partition *btrfs_part_info;
 
 int btrfs_devread(u64 address, int byte_len, void *buf)
 {
index 29076880bccc200efa5404ac3f23880eaedc9cfe..0d4f756aa5ca603b07720b833f140a6f06ad17e8 100644 (file)
@@ -33,9 +33,9 @@
 lbaint_t part_offset;
 
 static struct blk_desc *ext4fs_blk_desc;
-static disk_partition_t *part_info;
+static struct disk_partition *part_info;
 
-void ext4fs_set_blk_dev(struct blk_desc *rbdd, disk_partition_t *info)
+void ext4fs_set_blk_dev(struct blk_desc *rbdd, struct disk_partition *info)
 {
        assert(rbdd->blksz == (1 << rbdd->log2blksz));
        ext4fs_blk_desc = rbdd;
index 96ca276839e3733b113b4e95ad09396ede64ea9a..ad71f5ab6e256963c2a4afd20ca6f8ead630b6b8 100644 (file)
@@ -227,7 +227,7 @@ int ext4fs_read(char *buf, loff_t offset, loff_t len, loff_t *actread)
 }
 
 int ext4fs_probe(struct blk_desc *fs_dev_desc,
-                disk_partition_t *fs_partition)
+                struct disk_partition *fs_partition)
 {
        ext4fs_set_blk_dev(fs_dev_desc, fs_partition);
 
index f68c8f73c48828bb298c5821e56ed2c0b92679e3..425d877c749217c6b18ee891458525dee0402461 100644 (file)
@@ -36,7 +36,7 @@ static void downcase(char *str, size_t len)
 }
 
 static struct blk_desc *cur_dev;
-static disk_partition_t cur_part_info;
+static struct disk_partition cur_part_info;
 
 #define DOS_BOOT_MAGIC_OFFSET  0x1fe
 #define DOS_FS_TYPE_OFFSET     0x36
@@ -57,7 +57,7 @@ static int disk_read(__u32 block, __u32 nr_blocks, void *buf)
        return ret;
 }
 
-int fat_set_blk_dev(struct blk_desc *dev_desc, disk_partition_t *info)
+int fat_set_blk_dev(struct blk_desc *dev_desc, struct disk_partition *info)
 {
        ALLOC_CACHE_ALIGN_BUFFER(unsigned char, buffer, dev_desc->blksz);
 
@@ -88,7 +88,7 @@ int fat_set_blk_dev(struct blk_desc *dev_desc, disk_partition_t *info)
 
 int fat_register_device(struct blk_desc *dev_desc, int part_no)
 {
-       disk_partition_t info;
+       struct disk_partition info;
 
        /* First close any currently found FAT filesystem */
        cur_dev = NULL;
diff --git a/fs/fs.c b/fs/fs.c
index 0c66d6047703c76402c3e838b9a2e625492b99d2..e3de25da5b6ebe0ef5feda217c4611f93ad37f92 100644 (file)
--- a/fs/fs.c
+++ b/fs/fs.c
@@ -24,11 +24,11 @@ DECLARE_GLOBAL_DATA_PTR;
 
 static struct blk_desc *fs_dev_desc;
 static int fs_dev_part;
-static disk_partition_t fs_partition;
+static struct disk_partition fs_partition;
 static int fs_type = FS_TYPE_ANY;
 
 static inline int fs_probe_unsupported(struct blk_desc *fs_dev_desc,
-                                     disk_partition_t *fs_partition)
+                                     struct disk_partition *fs_partition)
 {
        printf("** Unrecognized filesystem type **\n");
        return -1;
@@ -135,7 +135,7 @@ struct fstype_info {
         */
        bool null_dev_desc_ok;
        int (*probe)(struct blk_desc *fs_dev_desc,
-                    disk_partition_t *fs_partition);
+                    struct disk_partition *fs_partition);
        int (*ls)(const char *dirname);
        int (*exists)(const char *filename);
        int (*size)(const char *filename, loff_t *size);
index d369c43ca68a3d9d088102f64feb5023597e6b10..1ff804d13ba85f86d2c7f73a26d4d6f0e109dea9 100644 (file)
@@ -10,7 +10,7 @@
 #include <part.h>
 #include <memalign.h>
 
-int fs_devread(struct blk_desc *blk, disk_partition_t *partition,
+int fs_devread(struct blk_desc *blk, struct disk_partition *partition,
               lbaint_t sector, int byte_offset, int byte_len, char *buf)
 {
        unsigned block_len;
index c6b67795df5c44f93770064f9d8c7cc2551ce8e1..5d9c26489aab66a2222d672d415b654f8d932918 100644 (file)
 #include "reiserfs_private.h"
 
 static struct blk_desc *reiserfs_blk_desc;
-static disk_partition_t *part_info;
+static struct disk_partition *part_info;
 
 
-void reiserfs_set_blk_dev(struct blk_desc *rbdd, disk_partition_t *info)
+void reiserfs_set_blk_dev(struct blk_desc *rbdd, struct disk_partition *info)
 {
        reiserfs_blk_desc = rbdd;
        part_info = info;
index af47224b6c6aa623644658ffba83c865a774ef9f..5851fe2434f5b563c3ce5fab53857c995d6118ae 100644 (file)
@@ -8,7 +8,7 @@
 #include <malloc.h>
 #include <os.h>
 
-int sandbox_fs_set_blk_dev(struct blk_desc *rbdd, disk_partition_t *info)
+int sandbox_fs_set_blk_dev(struct blk_desc *rbdd, struct disk_partition *info)
 {
        /*
         * Only accept a NULL struct blk_desc for the sandbox, which is when
index e097d284444959c857996b40d1b5b6bc6a515f23..742c2f47ebf6ebcd8fac4e90b64ba1e4c4f8336d 100644 (file)
@@ -549,7 +549,7 @@ static unsigned long ubifs_findfile(struct super_block *sb, char *filename)
        return 0;
 }
 
-int ubifs_set_blk_dev(struct blk_desc *rbdd, disk_partition_t *info)
+int ubifs_set_blk_dev(struct blk_desc *rbdd, struct disk_partition *info)
 {
        if (rbdd) {
                debug("UBIFS cannot be used with normal block devices\n");
index 3cdb9e03edc633f8faaea0a579cecdb90ebe84a9..251e7d1f74fc54c68596e65f553a97dfff7dbd09 100644 (file)
@@ -14,9 +14,9 @@
 #include <zfs_common.h>
 
 static struct blk_desc *zfs_blk_desc;
-static disk_partition_t *part_info;
+static struct disk_partition *part_info;
 
-void zfs_set_blk_dev(struct blk_desc *rbdd, disk_partition_t *info)
+void zfs_set_blk_dev(struct blk_desc *rbdd, struct disk_partition *info)
 {
        zfs_blk_desc = rbdd;
        part_info = info;
index 810906d22b3b0950cae008d30e98e4fdf624c8da..3f4e69be9ef727e6177897ca3f14c419511beaa5 100644 (file)
@@ -29,6 +29,6 @@
  * @param[in] part_info Place to store the partition information
  * @return The slot number (>= 0) on success, or a negative on error
  */
-int ab_select_slot(struct blk_desc *dev_desc, disk_partition_t *part_info);
+int ab_select_slot(struct blk_desc *dev_desc, struct disk_partition *part_info);
 
 #endif /* __ANDROID_AB_H */
index 18278f829e41c7c2c8e0cfc1018e225c6374936c..a8d7090f79442b0df8fd4f28b06c3c78dcacb4fa 100644 (file)
@@ -38,7 +38,7 @@ struct mmc_part {
        int dev_num;
        struct mmc *mmc;
        struct blk_desc *mmc_blk;
-       disk_partition_t info;
+       struct disk_partition info;
 };
 
 enum mmc_io_type {
index 5be61e3264ddd6e4b5c3f57da22762782727661d..f7f82ad7d1091d32f765bd52aaf72e6d4e1d1204 100644 (file)
@@ -8,7 +8,8 @@
 #ifndef __U_BOOT_BTRFS_H__
 #define __U_BOOT_BTRFS_H__
 
-int btrfs_probe(struct blk_desc *, disk_partition_t *);
+int btrfs_probe(struct blk_desc *fs_dev_desc,
+               struct disk_partition *fs_partition);
 int btrfs_ls(const char *);
 int btrfs_exists(const char *);
 int btrfs_size(const char *, loff_t *);
index 34585d407d06d9aa861ace1144af627163b77554..aafcd841402de7c53a51a3605414b8decd562ce7 100644 (file)
@@ -152,11 +152,11 @@ int ext4fs_exists(const char *filename);
 int ext4fs_size(const char *filename, loff_t *size);
 void ext4fs_free_node(struct ext2fs_node *node, struct ext2fs_node *currroot);
 int ext4fs_devread(lbaint_t sector, int byte_offset, int byte_len, char *buf);
-void ext4fs_set_blk_dev(struct blk_desc *rbdd, disk_partition_t *info);
+void ext4fs_set_blk_dev(struct blk_desc *rbdd, struct disk_partition *info);
 long int read_allocated_block(struct ext2_inode *inode, int fileblock,
                              struct ext_block_cache *cache);
 int ext4fs_probe(struct blk_desc *fs_dev_desc,
-                disk_partition_t *fs_partition);
+                struct disk_partition *fs_partition);
 int ext4_read_file(const char *filename, void *buf, loff_t offset, loff_t len,
                   loff_t *actread);
 int ext4_read_superblock(char *buffer);
index bc139f8c88c8c7a785e016aa5f33cbdf936b0f6d..84573fd3fe90869c92fc11b2c8f8f3fa6d2f2170 100644 (file)
@@ -193,7 +193,7 @@ int fat_size(const char *filename, loff_t *size);
 int file_fat_read_at(const char *filename, loff_t pos, void *buffer,
                     loff_t maxsize, loff_t *actread);
 int file_fat_read(const char *filename, void *buffer, int maxsize);
-int fat_set_blk_dev(struct blk_desc *rbdd, disk_partition_t *info);
+int fat_set_blk_dev(struct blk_desc *rbdd, struct disk_partition *info);
 int fat_register_device(struct blk_desc *dev_desc, int part_no);
 
 int file_fat_write(const char *filename, void *buf, loff_t offset, loff_t len,
index 95db001beee4afdf0e63bfdb5d20fab6ba9cd604..0c58109e2f86d3b9cc8cbd689cc5d8029c0bcdb4 100644 (file)
  *
  * @part_name: Named partition to lookup
  * @dev_desc: Pointer to returned blk_desc pointer
- * @part_info: Pointer to returned disk_partition_t
+ * @part_info: Pointer to returned struct disk_partition
  * @response: Pointer to fastboot response buffer
  */
 int fastboot_mmc_get_part_info(const char *part_name,
                               struct blk_desc **dev_desc,
-                              disk_partition_t *part_info, char *response);
+                              struct disk_partition *part_info,
+                              char *response);
 
 /**
  * fastboot_mmc_flash_write() - Write image to eMMC for fastboot
index 96d26032ac70726c9002e81bd2f5046e236b9081..3d4d25da960ecc82911b30e8473a9497e3c6ac16 100644 (file)
@@ -10,7 +10,7 @@
 
 #include <part.h>
 
-int fs_devread(struct blk_desc *, disk_partition_t *, lbaint_t, int, int,
+int fs_devread(struct blk_desc *, struct disk_partition *, lbaint_t, int, int,
               char *);
 
 #endif /* __U_BOOT_FS_INTERNAL_H__ */
index 3693527397eca90467aa1c3137e81f97811284f5..55be724d20f9a814a707adc20d25721ad16c6548 100644 (file)
@@ -54,7 +54,7 @@ struct block_drvr {
 #define PART_BOOTABLE                  ((int)BIT(0))
 #define PART_EFI_SYSTEM_PARTITION      ((int)BIT(1))
 
-typedef struct disk_partition {
+struct disk_partition {
        lbaint_t        start;  /* # of first block in partition        */
        lbaint_t        size;   /* number of blocks in partition        */
        ulong   blksz;          /* block size in bytes                  */
@@ -76,11 +76,11 @@ typedef struct disk_partition {
 #ifdef CONFIG_DOS_PARTITION
        uchar   sys_ind;        /* partition type                       */
 #endif
-} disk_partition_t;
+};
 
 struct disk_part {
        int partnum;
-       disk_partition_t gpt_part_info;
+       struct disk_partition gpt_part_info;
        struct list_head list;
 };
 
@@ -105,12 +105,14 @@ struct blk_desc *mg_disk_get_dev(int dev);
 int host_get_dev_err(int dev, struct blk_desc **blk_devp);
 
 /* disk/part.c */
-int part_get_info(struct blk_desc *dev_desc, int part, disk_partition_t *info);
+int part_get_info(struct blk_desc *dev_desc, int part,
+                 struct disk_partition *info);
 /**
  * part_get_info_whole_disk() - get partition info for the special case of
  * a partition occupying the entire disk.
  */
-int part_get_info_whole_disk(struct blk_desc *dev_desc, disk_partition_t *info);
+int part_get_info_whole_disk(struct blk_desc *dev_desc,
+                            struct disk_partition *info);
 
 void part_print(struct blk_desc *dev_desc);
 void part_init(struct blk_desc *dev_desc);
@@ -179,7 +181,7 @@ int blk_get_device_by_str(const char *ifname, const char *dev_str,
  */
 int blk_get_device_part_str(const char *ifname, const char *dev_part_str,
                            struct blk_desc **dev_desc,
-                           disk_partition_t *info, int allow_whole_dev);
+                           struct disk_partition *info, int allow_whole_dev);
 
 /**
  * part_get_info_by_name_type() - Search for a partition by name
@@ -194,7 +196,7 @@ int blk_get_device_part_str(const char *ifname, const char *dev_part_str,
  * otherwise error
  */
 int part_get_info_by_name_type(struct blk_desc *dev_desc, const char *name,
-                              disk_partition_t *info, int part_type);
+                              struct disk_partition *info, int part_type);
 
 /**
  * part_get_info_by_name() - Search for a partition by name
@@ -208,7 +210,7 @@ int part_get_info_by_name_type(struct blk_desc *dev_desc, const char *name,
  * otherwise error
  */
 int part_get_info_by_name(struct blk_desc *dev_desc,
-                             const char *name, disk_partition_t *info);
+                             const char *name, struct disk_partition *info);
 
 /**
  * Get partition info from dev number + part name, or dev number + part number.
@@ -229,7 +231,7 @@ int part_get_info_by_name(struct blk_desc *dev_desc,
 int part_get_info_by_dev_and_name_or_num(const char *dev_iface,
                                         const char *dev_part_str,
                                         struct blk_desc **dev_desc,
-                                        disk_partition_t *part_info);
+                                        struct disk_partition *part_info);
 
 /**
  * part_set_generic_name() - create generic partition like hda1 or sdb2
@@ -252,9 +254,9 @@ static inline struct blk_desc *blk_get_dev(const char *ifname, int dev)
 static inline struct blk_desc *mg_disk_get_dev(int dev) { return NULL; }
 
 static inline int part_get_info(struct blk_desc *dev_desc, int part,
-                               disk_partition_t *info) { return -1; }
+                               struct disk_partition *info) { return -1; }
 static inline int part_get_info_whole_disk(struct blk_desc *dev_desc,
-                                          disk_partition_t *info)
+                                          struct disk_partition *info)
 { return -1; }
 static inline void part_print(struct blk_desc *dev_desc) {}
 static inline void part_init(struct blk_desc *dev_desc) {}
@@ -263,10 +265,10 @@ static inline int blk_get_device_by_str(const char *ifname, const char *dev_str,
                                        struct blk_desc **dev_desc)
 { return -1; }
 static inline int blk_get_device_part_str(const char *ifname,
-                                          const char *dev_part_str,
-                                          struct blk_desc **dev_desc,
-                                          disk_partition_t *info,
-                                          int allow_whole_dev)
+                                         const char *dev_part_str,
+                                         struct blk_desc **dev_desc,
+                                         struct disk_partition *info,
+                                         int allow_whole_dev)
 { *dev_desc = NULL; return -1; }
 #endif
 
@@ -301,7 +303,7 @@ struct part_driver {
         * @info:       Returns partition information
         */
        int (*get_info)(struct blk_desc *dev_desc, int part,
-                       disk_partition_t *info);
+                       struct disk_partition *info);
 
        /**
         * print() - Print partition information
@@ -353,7 +355,7 @@ int write_gpt_table(struct blk_desc *dev_desc,
  */
 int gpt_fill_pte(struct blk_desc *dev_desc,
                 gpt_header *gpt_h, gpt_entry *gpt_e,
-                disk_partition_t *partitions, int parts);
+                struct disk_partition *partitions, int parts);
 
 /**
  * gpt_fill_header(): Fill the GPT header
@@ -379,7 +381,7 @@ int gpt_fill_header(struct blk_desc *dev_desc, gpt_header *gpt_h,
  * @return zero on success
  */
 int gpt_restore(struct blk_desc *dev_desc, char *str_disk_guid,
-               disk_partition_t *partitions, const int parts_count);
+               struct disk_partition *partitions, const int parts_count);
 
 /**
  * is_valid_gpt_buf() - Ensure that the Primary GPT information is valid
@@ -433,7 +435,7 @@ int gpt_verify_headers(struct blk_desc *dev_desc, gpt_header *gpt_head,
  * @return - '0' on success, otherwise error
  */
 int gpt_verify_partitions(struct blk_desc *dev_desc,
-                         disk_partition_t *partitions, int parts,
+                         struct disk_partition *partitions, int parts,
                          gpt_header *gpt_head, gpt_entry **gpt_pte);
 
 
index de4150024cef1514d1d8903e57a110129a0e656b..a655d5ea9fce4fc24a0db4d2cb995e7ebd1a1763 100644 (file)
@@ -62,7 +62,7 @@ typedef enum
 } reiserfs_error_t;
 
 
-void reiserfs_set_blk_dev(struct blk_desc *rbdd, disk_partition_t *info);
+void reiserfs_set_blk_dev(struct blk_desc *rbdd, struct disk_partition *info);
 extern int reiserfs_ls (char *dirname);
 extern int reiserfs_open (char *filename);
 extern int reiserfs_read (char *buf, unsigned len);
index 6e6e3c62ff9612c2e1458ad52bc58b5f8ac4b1d6..49724d05c89fc23cc70d1e203b28b4be9ca428ae 100644 (file)
@@ -18,7 +18,7 @@
 #ifndef __SANDBOX_FS__
 #define __SANDBOX_FS__
 
-int sandbox_fs_set_blk_dev(struct blk_desc *rbdd, disk_partition_t *info);
+int sandbox_fs_set_blk_dev(struct blk_desc *rbdd, struct disk_partition *info);
 
 int sandbox_fs_read_at(const char *filename, loff_t pos, void *buffer,
                       loff_t maxsize, loff_t *actread);
index 015ce122266f378728a55c7088f9cb7421a934d0..16b757286e40386b932bb01ae8017f5ead04f4d8 100644 (file)
@@ -20,7 +20,7 @@ void uboot_ubifs_umount(void);
 int ubifs_is_mounted(void);
 int ubifs_load(char *filename, u32 addr, u32 size);
 
-int ubifs_set_blk_dev(struct blk_desc *rbdd, disk_partition_t *info);
+int ubifs_set_blk_dev(struct blk_desc *rbdd, struct disk_partition *info);
 int ubifs_ls(const char *dir_name);
 int ubifs_exists(const char *filename);
 int ubifs_size(const char *filename, loff_t *size);
index bca3dff06e1a83e9ada821a8564e18e7d69c8502..027ba91b28740285a8a38962545f4568fec16859 100644 (file)
@@ -98,7 +98,7 @@ int zfs_close(zfs_file_t);
 int zfs_ls(device_t dev, const char *path,
                   int (*hook) (const char *, const struct zfs_dirhook_info *));
 int zfs_devread(int sector, int byte_offset, int byte_len, char *buf);
-void zfs_set_blk_dev(struct blk_desc *rbdd, disk_partition_t *info);
+void zfs_set_blk_dev(struct blk_desc *rbdd, struct disk_partition *info);
 void zfs_unmount(struct zfs_data *data);
 int lzjb_decompress(void *, void *, uint32_t, uint32_t);
 #endif
index 5b2ff813191cb2e27e9920433b93cfb363b3e103..76ab2d82886a1f1a72eae8199f0e24b84a6d88ed 100644 (file)
@@ -694,7 +694,7 @@ static unsigned dp_part_size(struct blk_desc *desc, int part)
  */
 static void *dp_part_node(void *buf, struct blk_desc *desc, int part)
 {
-       disk_partition_t info;
+       struct disk_partition info;
 
        part_get_info(desc, part, &info);
 
@@ -1036,7 +1036,7 @@ efi_status_t efi_dp_from_name(const char *dev, const char *devnr,
 {
        int is_net;
        struct blk_desc *desc = NULL;
-       disk_partition_t fs_partition;
+       struct disk_partition fs_partition;
        int part = 0;
        char filename[32] = { 0 }; /* dp->str is u16[32] long */
        char *s;
index 0582e02158fc172179e0c407bccd505773d6c65f..9176008c0eaa4cf70fdbd0430b5870f892082e83 100644 (file)
@@ -424,7 +424,7 @@ static efi_status_t efi_disk_add_dev(
        /* Store first EFI system partition */
        if (part && !efi_system_partition.if_type) {
                int r;
-               disk_partition_t info;
+               struct disk_partition info;
 
                r = part_get_info(desc, part, &info);
                if (r)
@@ -459,7 +459,7 @@ int efi_disk_create_partitions(efi_handle_t parent, struct blk_desc *desc,
 {
        int disks = 0;
        char devname[32] = { 0 }; /* dp->str is u16[32] long */
-       disk_partition_t info;
+       struct disk_partition info;
        int part;
        struct efi_device_path *dp = NULL;
        efi_status_t ret;
@@ -600,7 +600,7 @@ bool efi_disk_is_system_part(efi_handle_t handle)
 {
        struct efi_handler *handler;
        struct efi_disk_obj *diskobj;
-       disk_partition_t info;
+       struct disk_partition info;
        efi_status_t ret;
        int r;
 
index 140116ddc4ace7ccd2e1916aad62b9a1bb47c498..1fe7cf539e3900c4412612e983c815f4b42794d3 100644 (file)
@@ -634,7 +634,7 @@ static efi_status_t EFIAPI efi_file_getinfo(struct efi_file_handle *file,
                utf8_utf16_strcpy(&dst, filename);
        } else if (!guidcmp(info_type, &efi_file_system_info_guid)) {
                struct efi_file_system_info *info = buffer;
-               disk_partition_t part;
+               struct disk_partition part;
                efi_uintn_t required_size;
                int r;
--- a/cmd/zfs.c
+++ b/cmd/zfs.c
@@ -38,7 +38,7 @@ static int do_zfs_load(cmd_tbl_t *cmdtp, int flag, int argc, char * const argv[]
        int dev;
        int part;
        ulong addr = 0;
-       disk_partition_t info;
+       struct disk_partition info;
        struct blk_desc *dev_desc;
        unsigned long count;
        const char *addr_str;
@@ -135,7 +135,7 @@ static int do_zfs_ls(cmd_tbl_t *cmdtp, int flag, int argc, char * const argv[])
        const char *filename = "/";
        int part;
        struct blk_desc *dev_desc;
-       disk_partition_t info;
+       struct disk_partition info;
        struct device_s vdev;
 
        if (argc < 2)
index e0fe32d24da5b1cd616a3bd3f08ba16547c8c871..b5b8af1b2784be5805134ccfc17a2ce521512f47 100644 (file)
@@ -81,7 +81,7 @@ static int ab_control_default(struct bootloader_control *abc)
  * @return 0 on success and a negative on error
  */
 static int ab_control_create_from_disk(struct blk_desc *dev_desc,
-                                      const disk_partition_t *part_info,
+                                      const struct disk_partition *part_info,
                                       struct bootloader_control **abc)
 {
        ulong abc_offset, abc_blocks, ret;
@@ -131,7 +131,7 @@ static int ab_control_create_from_disk(struct blk_desc *dev_desc,
  * @return 0 on success and a negative on error
  */
 static int ab_control_store(struct blk_desc *dev_desc,
-                           const disk_partition_t *part_info,
+                           const struct disk_partition *part_info,
                            struct bootloader_control *abc)
 {
        ulong abc_offset, abc_blocks, ret;
@@ -178,7 +178,7 @@ static int ab_compare_slots(const struct slot_metadata *a,
        return 0;
 }
 
-int ab_select_slot(struct blk_desc *dev_desc, disk_partition_t *part_info)
+int ab_select_slot(struct blk_desc *dev_desc, struct disk_partition *part_info)
 {
        struct bootloader_control *abc = NULL;
        u32 crc32_le;
index 2a6252229ca157f2b3534ea12214bfb0cbc412fb..954133ba84e9841b2646810f19dfe275603895f4 100644 (file)
@@ -15,7 +15,7 @@ int spl_load_image_ext(struct spl_image_info *spl_image,
        s32 err;
        struct image_header *header;
        loff_t filelen, actlen;
-       disk_partition_t part_info = {};
+       struct disk_partition part_info = {};
 
        header = spl_get_load_buffer(-sizeof(*header), sizeof(*header));
 
@@ -69,7 +69,7 @@ int spl_load_image_ext_os(struct spl_image_info *spl_image,
 {
        int err;
        __maybe_unused loff_t filelen, actlen;
-       disk_partition_t part_info = {};
+       struct disk_partition part_info = {};
        __maybe_unused char *file;
 
        if (part_get_info(block_dev, partition, &part_info)) {
index a68cdec8dc8f5e15c0751555f9328df76125799a..fcdd3caeac76efa1d03fc74125aeacfb783b2ddf 100644 (file)
@@ -168,7 +168,7 @@ static int mmc_load_image_raw_partition(struct spl_image_info *spl_image,
                                        struct mmc *mmc, int partition,
                                        unsigned long sector)
 {
-       disk_partition_t info;
+       struct disk_partition info;
        int err;
 
 #ifdef CONFIG_SYS_MMCSD_RAW_MODE_U_BOOT_USE_PARTITION_TYPE
index 4cc2fc19f7e3ab22ddaf1faf48cc3871f6f6ac56..68cba61c5a05a864b1bc03f44246c7f3cbe86b0e 100644 (file)
@@ -318,7 +318,7 @@ void part_print(struct blk_desc *dev_desc)
 #endif /* CONFIG_HAVE_BLOCK_DEVICE */
 
 int part_get_info(struct blk_desc *dev_desc, int part,
-                      disk_partition_t *info)
+                      struct disk_partition *info)
 {
 #ifdef CONFIG_HAVE_BLOCK_DEVICE
        struct part_driver *drv;
@@ -351,7 +351,8 @@ int part_get_info(struct blk_desc *dev_desc, int part,
        return -1;
 }
 
-int part_get_info_whole_disk(struct blk_desc *dev_desc, disk_partition_t *info)
+int part_get_info_whole_disk(struct blk_desc *dev_desc,
+                            struct disk_partition *info)
 {
        info->start = 0;
        info->size = dev_desc->lba;
@@ -431,7 +432,7 @@ cleanup:
 #define PART_AUTO -1
 int blk_get_device_part_str(const char *ifname, const char *dev_part_str,
                             struct blk_desc **dev_desc,
-                            disk_partition_t *info, int allow_whole_dev)
+                            struct disk_partition *info, int allow_whole_dev)
 {
        int ret = -1;
        const char *part_str;
@@ -441,7 +442,7 @@ int blk_get_device_part_str(const char *ifname, const char *dev_part_str,
        char *ep;
        int p;
        int part;
-       disk_partition_t tmpinfo;
+       struct disk_partition tmpinfo;
 
 #ifdef CONFIG_SANDBOX
        /*
@@ -646,7 +647,7 @@ cleanup:
 }
 
 int part_get_info_by_name_type(struct blk_desc *dev_desc, const char *name,
-                              disk_partition_t *info, int part_type)
+                              struct disk_partition *info, int part_type)
 {
        struct part_driver *part_drv;
        int ret;
@@ -671,7 +672,7 @@ int part_get_info_by_name_type(struct blk_desc *dev_desc, const char *name,
 }
 
 int part_get_info_by_name(struct blk_desc *dev_desc, const char *name,
-                         disk_partition_t *info)
+                         struct disk_partition *info)
 {
        return part_get_info_by_name_type(dev_desc, name, info, PART_TYPE_ALL);
 }
@@ -693,7 +694,7 @@ int part_get_info_by_name(struct blk_desc *dev_desc, const char *name,
 static int part_get_info_by_dev_and_name(const char *dev_iface,
                                         const char *dev_part_str,
                                         struct blk_desc **dev_desc,
-                                        disk_partition_t *part_info)
+                                        struct disk_partition *part_info)
 {
        char *ep;
        const char *part_str;
@@ -725,7 +726,7 @@ static int part_get_info_by_dev_and_name(const char *dev_iface,
 int part_get_info_by_dev_and_name_or_num(const char *dev_iface,
                                         const char *dev_part_str,
                                         struct blk_desc **dev_desc,
-                                        disk_partition_t *part_info)
+                                        struct disk_partition *part_info)
 {
        /* Split the part_name if passed as "$dev_num#part_name". */
        if (!part_get_info_by_dev_and_name(dev_iface, dev_part_str,
index 5a2bb718b5973e883a99982bc279bf68125b9eca..5a17d11b9b7950ed502cfa6aa9c2673b7d77eabc 100644 (file)
@@ -291,7 +291,7 @@ static struct partition_block *find_partition(struct blk_desc *dev_desc,
  * Get info about a partition
  */
 static int part_get_info_amiga(struct blk_desc *dev_desc, int part,
-                                   disk_partition_t *info)
+                                   struct disk_partition *info)
 {
     struct partition_block *p = find_partition(dev_desc, part-1);
     struct amiga_part_geometry *g;
index 813379f851ef500c928653d732c8a3bcfab59e02..6e2a11090cb4648158e21c99425cf9e9f7314740 100644 (file)
@@ -213,7 +213,7 @@ static void print_partition_extended(struct blk_desc *dev_desc,
 static int part_get_info_extended(struct blk_desc *dev_desc,
                                  lbaint_t ext_part_sector, lbaint_t relative,
                                  int part_num, int which_part,
-                                 disk_partition_t *info, unsigned int disksig)
+                                 struct disk_partition *info, uint disksig)
 {
        ALLOC_CACHE_ALIGN_BUFFER(unsigned char, buffer, dev_desc->blksz);
        dos_partition_t *pt;
@@ -317,7 +317,7 @@ void part_print_dos(struct blk_desc *dev_desc)
 }
 
 int part_get_info_dos(struct blk_desc *dev_desc, int part,
-                     disk_partition_t *info)
+                     struct disk_partition *info)
 {
        return part_get_info_extended(dev_desc, 0, 0, 1, part, info, 0);
 }
index de15a37cd518152a393d4283561f654cc3b248cd..6b206ddb4fb1ee53c427ecd7adf09b8cd425dd64 100644 (file)
@@ -259,7 +259,7 @@ void part_print_efi(struct blk_desc *dev_desc)
 }
 
 int part_get_info_efi(struct blk_desc *dev_desc, int part,
-                     disk_partition_t *info)
+                     struct disk_partition *info)
 {
        ALLOC_CACHE_ALIGN_BUFFER_PAD(gpt_header, gpt_head, 1, dev_desc->blksz);
        gpt_entry *gpt_pte = NULL;
@@ -413,7 +413,7 @@ int write_gpt_table(struct blk_desc *dev_desc,
 
 int gpt_fill_pte(struct blk_desc *dev_desc,
                 gpt_header *gpt_h, gpt_entry *gpt_e,
-                disk_partition_t *partitions, int parts)
+                struct disk_partition *partitions, int parts)
 {
        lbaint_t offset = (lbaint_t)le64_to_cpu(gpt_h->first_usable_lba);
        lbaint_t last_usable_lba = (lbaint_t)
@@ -603,7 +603,7 @@ int gpt_fill_header(struct blk_desc *dev_desc, gpt_header *gpt_h,
 }
 
 int gpt_restore(struct blk_desc *dev_desc, char *str_disk_guid,
-               disk_partition_t *partitions, int parts_count)
+               struct disk_partition *partitions, int parts_count)
 {
        gpt_header *gpt_h;
        gpt_entry *gpt_e;
@@ -698,7 +698,7 @@ int gpt_verify_headers(struct blk_desc *dev_desc, gpt_header *gpt_head,
 }
 
 int gpt_verify_partitions(struct blk_desc *dev_desc,
-                         disk_partition_t *partitions, int parts,
+                         struct disk_partition *partitions, int parts,
                          gpt_header *gpt_head, gpt_entry **gpt_pte)
 {
        char efi_str[PARTNAME_SZ + 1];
index 4f14c9a56e2980888c696c69db259145f549ddb0..2ccb7867c9b846ec287b6207fcbe23a91068b7e0 100644 (file)
@@ -47,7 +47,7 @@ unsigned long iso_dread(struct blk_desc *block_dev, lbaint_t start,
 
 /* only boot records will be listed as valid partitions */
 int part_get_info_iso_verb(struct blk_desc *dev_desc, int part_num,
-                          disk_partition_t *info, int verb)
+                          struct disk_partition *info, int verb)
 {
        int i,offset,entry_num;
        unsigned short *chksumbuf;
@@ -200,14 +200,14 @@ found:
 }
 
 static int part_get_info_iso(struct blk_desc *dev_desc, int part_num,
-                                 disk_partition_t *info)
+                            struct disk_partition *info)
 {
        return part_get_info_iso_verb(dev_desc, part_num, info, 0);
 }
 
 static void part_print_iso(struct blk_desc *dev_desc)
 {
-       disk_partition_t info;
+       struct disk_partition info;
        int i;
 
        if (part_get_info_iso_verb(dev_desc, 1, &info, 0) == -1) {
@@ -226,7 +226,7 @@ static void part_print_iso(struct blk_desc *dev_desc)
 
 static int part_test_iso(struct blk_desc *dev_desc)
 {
-       disk_partition_t info;
+       struct disk_partition info;
 
        return part_get_info_iso_verb(dev_desc, 1, &info, 0);
 }
index 8b2c004027cf11d1ec44a9dbe7bb2ee34a7793d4..fbd0ad73e35ddfc3b2f7eb4eba5b3d573bd60133 100644 (file)
@@ -214,7 +214,7 @@ static int part_mac_read_pdb(struct blk_desc *dev_desc, int part,
 }
 
 static int part_get_info_mac(struct blk_desc *dev_desc, int part,
-                                 disk_partition_t *info)
+                                 struct disk_partition *info)
 {
        ALLOC_CACHE_ALIGN_BUFFER(mac_driver_desc_t, ddesc, 1);
        ALLOC_CACHE_ALIGN_BUFFER(mac_partition_t, mpart, 1);
index 0d495a785bc3200e5b5ad4300761abe18a16dc57..cddca0c45fe3f327e3d06543c9d208c6cd53a645 100644 (file)
@@ -369,7 +369,7 @@ int dfu_fill_entity_mmc(struct dfu_entity *dfu, char *devstr, char *s)
                                        simple_strtoul(s, NULL, 0);
 
        } else if (!strcmp(entity_type, "part")) {
-               disk_partition_t partinfo;
+               struct disk_partition partinfo;
                struct blk_desc *blk_dev = mmc_get_blk_desc(mmc);
                int mmcdev = second_arg;
                int mmcpart = third_arg;
index 95cb4341895fcbc3938a035aaa1463f822abd0a5..467a8618fe3cf80e5611a8a7c7b018e630137719 100644 (file)
@@ -103,7 +103,7 @@ static int getvar_get_part_info(const char *part_name, char *response,
        int r;
 # if CONFIG_IS_ENABLED(FASTBOOT_FLASH_MMC)
        struct blk_desc *dev_desc;
-       disk_partition_t part_info;
+       struct disk_partition part_info;
 
        r = fastboot_mmc_get_part_info(part_name, &dev_desc, &part_info,
                                       response);
@@ -219,7 +219,7 @@ static void getvar_partition_type(char *part_name, char *response)
 {
        int r;
        struct blk_desc *dev_desc;
-       disk_partition_t part_info;
+       struct disk_partition part_info;
 
        r = fastboot_mmc_get_part_info(part_name, &dev_desc, &part_info,
                                       response);
index d3249a54f7c75c1c6b2fbccaffe192de1b4221c1..c666eb0f29b032da78c7254516ea2c439d672bca 100644 (file)
@@ -27,7 +27,7 @@ struct fb_mmc_sparse {
 };
 
 static int part_get_info_by_name_or_alias(struct blk_desc *dev_desc,
-               const char *name, disk_partition_t *info)
+               const char *name, struct disk_partition *info)
 {
        int ret;
 
@@ -98,9 +98,9 @@ static lbaint_t fb_mmc_sparse_reserve(struct sparse_storage *info,
        return blkcnt;
 }
 
-static void write_raw_image(struct blk_desc *dev_desc, disk_partition_t *info,
-               const char *part_name, void *buffer,
-               u32 download_bytes, char *response)
+static void write_raw_image(struct blk_desc *dev_desc,
+                           struct disk_partition *info, const char *part_name,
+                           void *buffer, u32 download_bytes, char *response)
 {
        lbaint_t blkcnt;
        lbaint_t blks;
@@ -211,7 +211,7 @@ static void fb_mmc_boot1_ops(struct blk_desc *dev_desc, void *buffer,
  * @return Boot image header sectors count or 0 on error
  */
 static lbaint_t fb_mmc_get_boot_header(struct blk_desc *dev_desc,
-                                      disk_partition_t *info,
+                                      struct disk_partition *info,
                                       struct andr_img_hdr *hdr,
                                       char *response)
 {
@@ -271,7 +271,7 @@ static int fb_mmc_update_zimage(struct blk_desc *dev_desc,
        u32 kernel_sector_start;
        u32 kernel_sectors;
        u32 sectors_per_page;
-       disk_partition_t info;
+       struct disk_partition info;
        int res;
 
        puts("Flashing zImage\n");
@@ -367,12 +367,12 @@ static int fb_mmc_update_zimage(struct blk_desc *dev_desc,
  *
  * @part_name: Named partition to lookup
  * @dev_desc: Pointer to returned blk_desc pointer
* @part_info: Pointer to returned disk_partition_t
  * @response: Pointer to fastboot response buffer
  */
 int fastboot_mmc_get_part_info(const char *part_name,
                               struct blk_desc **dev_desc,
-                              disk_partition_t *part_info, char *response)
+                              struct disk_partition *part_info, char *response)
 {
        int r;
 
@@ -407,7 +407,7 @@ void fastboot_mmc_flash_write(const char *cmd, void *download_buffer,
                              u32 download_bytes, char *response)
 {
        struct blk_desc *dev_desc;
-       disk_partition_t info;
+       struct disk_partition info;
 
        dev_desc = blk_get_dev("mmc", CONFIG_FASTBOOT_FLASH_MMC_DEV);
        if (!dev_desc || dev_desc->type == DEV_TYPE_UNKNOWN) {
@@ -524,7 +524,7 @@ void fastboot_mmc_erase(const char *cmd, char *response)
 {
        int ret;
        struct blk_desc *dev_desc;
-       disk_partition_t info;
+       struct disk_partition info;
        lbaint_t blks, blks_start, blks_size, grp_size;
        struct mmc *mmc = find_mmc_device(CONFIG_FASTBOOT_FLASH_MMC_DEV);
 
index 911e19c6d3d7e9f54fdbe3b634b2c6d4f4954769..6b5c4d855a1ae7693b7de03c993bf0be8ec74a8b 100644 (file)
@@ -45,7 +45,7 @@ static int env_ext4_save(void)
 {
        env_t   env_new;
        struct blk_desc *dev_desc = NULL;
-       disk_partition_t info;
+       struct disk_partition info;
        int dev, part;
        int err;
        const char *ifname = env_ext4_get_intf();
@@ -87,7 +87,7 @@ static int env_ext4_load(void)
 {
        ALLOC_CACHE_ALIGN_BUFFER(char, buf, CONFIG_ENV_SIZE);
        struct blk_desc *dev_desc = NULL;
-       disk_partition_t info;
+       struct disk_partition info;
        int dev, part;
        int err;
        loff_t off;
@@ -367,12 +367,12 @@ static int fb_mmc_update_zimage(struct blk_desc *dev_desc,
  * @part_name: Named partition to lookup
  * @dev_desc: Pointer to returned blk_desc pointer
- * @part_info: Pointer to returned disk_partition_t
+ * @part_info: Pointer to returned struct disk_partition
  * @response: Pointer to fastboot response buffer
  */
index 9772b87a19133f6a808909c5d65a98b600d980a2..f13b88b5f62ef2d4f4d952a16883e8aa6fc958c3 100644 (file)